host_users

Function host_users 

pub fn host_users<'a, 'str: 'a>(
    host: impl QCodeView<'a, 'str>,
    v: ValueId,
) -> Vec<InstructionId>
This host’s users of v. Allocates; prefer has_users to ask whether there are any, and users_of_slice to look at them in a hot loop.